SystemOrganization addCategory: #ConfigurationOfOmniVM!

Object subclass: #ConfigurationOfOmniVM
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfOmniVM'!

!ConfigurationOfOmniVM class methodsFor: 'development support' stamp: 'StefanMarr 8/6/2012 17:09'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfOmniVM class methodsFor: 'private' stamp: 'StefanMarr 8/6/2012 17:09'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfOmniVM class methodsFor: 'private' stamp: 'StefanMarr 8/6/2012 17:09'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfOmniVM class methodsFor: 'private' stamp: 'StefanMarr 8/6/2012 17:09'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfOmniVM class methodsFor: 'metacello tool support' stamp: 'StefanMarr 8/6/2012 17:09'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfOmniVM class methodsFor: 'loading' stamp: 'StefanMarr 8/6/2012 17:09'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfOmniVM class methodsFor: 'loading' stamp: 'StefanMarr 8/6/2012 17:09'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfOmniVM class methodsFor: 'loading' stamp: 'StefanMarr 8/6/2012 17:09'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfOmniVM class methodsFor: 'loading' stamp: 'StefanMarr 1/16/2013 15:29'!
loadPhD2013
	"This configuration reflects the project status used for benchmarks in my PhD dissertation"

	"self loadPhD2013"

	<apiDocumentation>
	^(self project version: #'phd2013') load! !

!ConfigurationOfOmniVM class methodsFor: 'accessing' stamp: 'StefanMarr 8/6/2012 17:09'!
project

	^self new project! !

!ConfigurationOfOmniVM class methodsFor: 'development support' stamp: 'StefanMarr 8/6/2012 17:09'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfOmniVM methodsFor: 'baselines' stamp: 'StefanMarr 1/16/2013 15:46'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		
		"SMark benchmarking"
		spec project: 'Benchmarking' with: [
				spec
					className: 'ConfigurationOfBenchmarking';
					versionString: '0.2';
					repository: 'http://www.squeaksource.com/SMark' ].
		
		"RoarVM compatibility"
		spec package: 'RoarVM' with: [spec repository: 'http://ss3.gemstone.com/ss/RoarVM'].
		
		"Omni-related"
		spec repository: 'http://ss3.gemstone.com/ss/Omni'.
		
		spec
			package: 'OmniVMNoOpt' with: [
				spec requires: #('RoarVM')];
	
			package: 'ClojureST' with: [
				spec requires: #('OmniVMNoOpt')];
			
			package: 'OmniST-Languages' with: [
				spec requires: #('OmniVMNoOpt' 'ClojureST')];
			
			package: 'CLBG-Compatibility' with: [
				spec requires: #('OmniVMNoOpt' 'Benchmarking')];
			package: 'OmniST-CLBG-Compatibility' with: [ "Omni Object classes"
				spec requires: #('Benchmarking' 'CLBG-Compatibility')];
			 
			package: 'OmniST-Benchmarks' with: [
				spec requires: #('OmniVMNoOpt' 'OmniST-Languages' 'OmniST-CLBG-Compatibility')];
			
			package: 'OmniST-Tests-Core' with: [
				spec requires: #('OmniVMNoOpt')];
			
			package: 'OmniST-Tests-Languages' with: [
				spec requires: #('OmniST-Languages')];
			
			package: 'AmbientTalkST-Benchmarks' with: [
				spec requires: #('OmniST-Languages' 'OmniST-Benchmarks')].
		
		"LRSTM packages"
		spec package: 'LRSTM-Benchmarks' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM'].
		spec package: 'LRSTM-Tests' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM']		
		].
! !

!ConfigurationOfOmniVM methodsFor: 'baselines' stamp: 'StefanMarr 1/16/2013 15:46'!
baseline02: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		
		"SMark benchmarking"
		spec project: 'Benchmarking' with: [
				spec
					className: 'ConfigurationOfBenchmarking';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/SMark' ].
		
		"RoarVM compatibility"
		spec package: 'RoarVM' with: [spec repository: 'http://ss3.gemstone.com/ss/RoarVM'].
		
		"Omni-related"
		spec repository: 'http://ss3.gemstone.com/ss/Omni'.
		
		spec
			package: 'OmniVMNoOpt' with: [
				spec requires: #('RoarVM')];
	
			package: 'ClojureST' with: [
				spec requires: #('OmniVMNoOpt')];
			
			package: 'OmniST-Languages' with: [
				spec requires: #('OmniVMNoOpt' 'ClojureST')];
			
			package: 'CLBG-Compatibility' with: [
				spec requires: #('OmniVMNoOpt' 'Benchmarking')];
			package: 'OmniST-CLBG-Compatibility' with: [ "Omni Object classes"
				spec requires: #('Benchmarking' 'CLBG-Compatibility')];
			 
			package: 'OmniST-Benchmarks' with: [
				spec requires: #('OmniVMNoOpt' 'OmniST-Languages' 'OmniST-CLBG-Compatibility')];
			
			package: 'OmniST-Tests-Core' with: [
				spec requires: #('OmniVMNoOpt')];
			
			package: 'OmniST-Tests-Languages' with: [
				spec requires: #('OmniST-Languages')];
			
			package: 'AmbientTalkST-Benchmarks' with: [
				spec requires: #('OmniST-Languages' 'OmniST-Benchmarks')].
		
		"LRSTM packages"
		spec package: 'LRSTM-Benchmarks' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM'].
		spec package: 'LRSTM-Tests' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM']		
		].
! !

!ConfigurationOfOmniVM methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/16/2013 15:28'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.2-baseline'.
! !

!ConfigurationOfOmniVM methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/16/2013 15:28'!
phd2013: spec
	<symbolicVersion: #'phd2013'>

	spec for: #'common' version: '0.1-phd2013'! !

!ConfigurationOfOmniVM methodsFor: 'accessing' stamp: 'StefanMarr 8/6/2012 17:09'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfOmniVM methodsFor: 'as yet unclassified' stamp: 'StefanMarr 1/16/2013 15:53'!
version01: spec
	<version: '0.1-phd2013' imports: #('0.1-baseline') >

	spec for: #'common' do: [
		spec blessing: #'phd2013'.
		spec description: 'Configuration reflecting the project status used for benchmarks in my PhD dissertation'.
		spec author: 'StefanMarr'.
		spec timestamp: '1/16/2013 15:29'.
	
		spec
			package: 'RoarVM' 						with: 'RoarVM-StefanMarr.10';
			package: 'OmniVMNoOpt' 					with: 'OmniVMNoOpt-StefanMarr.28';
			package: 'ClojureST'					with: 'ClojureST-StefanMarr.3';
			package: 'OmniST-Languages'			with: 'OmniST-Languages-StefanMarr.43';
			package: 'CLBG-Compatibility'			with: 'CLBG-Compatibility-StefanMarr.1';
			package: 'OmniST-CLBG-Compatibility'	with: 'OmniST-CLBG-Compatibility-StefanMarr.4';
			package: 'OmniST-Benchmarks'			with: 'OmniST-Benchmarks-StefanMarr.20';
			package: 'OmniST-Tests-Core'			with: 'OmniST-Tests-Core-StefanMarr.28';
			package: 'OmniST-Tests-Languages' 	with: 'OmniST-Tests-Languages-StefanMarr.27';
			package: 'AmbientTalkST-Benchmarks'	with: 'AmbientTalkST-Benchmarks-StefanMarr.27';
			package: 'LRSTM-Benchmarks'			with: 'LRSTM-Benchmarks-StefanMarr.1';
			package: 'LRSTM-Tests'					with: 'LRSTM-Tests-StefanMarr.1'
	].! !
